#This file is part of Tryton.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.

from trytond.pool import PoolMeta


__all__ = ['Lang']
__metaclass__ = PoolMeta


class Lang:
    __name__ = "ir.lang"

    @classmethod
    def __setup__(cls):
        super(Lang, cls).__setup__()

        lang_co = cls.search([
            ('code', '=', 'es_CO'),
            ])
        if lang_co:
            lang_co = lang_co[0]
            if lang_co.thousands_sep == None:
                cls.write([lang_co], {'thousands_sep': '.'})
